@@ -20,7 +20,7 @@ TASK_FILE_LOCATION = f"{HOME_DIR}/.sylo/tasks.dat"
 CONFIG_FILE_LOCATION = f"{HOME_DIR}/.sylo/sylo.cfg"
 
 HOME_DIR_CREATE = f"mkdir {HOME_DIR}/.sylo"
-DATA_FILE_CREATE = f'echo "{TODAY_STR},0,0" > {DATA_FILE_LOCATION}'
+DATA_FILE_CREATE = f'echo "{TODAY_STR},0,0,0" > {DATA_FILE_LOCATION}'
 TASK_FILE_CREATE = f"touch {TASK_FILE_LOCATION}"
 
 WELCOME_CHOICES = ("", "h", "q", "s", "i", "t", "y", "a")
@@ -38,6 +38,6 @@ TIMER_DEFAULTS = {
 
 COUNTDOWN_INCREMENTS = 1
 
-METRICS_HEAT = 'termgraph --calendar --start-dt "%s" %s '
+METRICS_HEAT = 'termgraph --calendar --start-dt "%s" %s 2>/dev/null'
 
-METRICS_BAR = 'termgraph %s --color {red,green} --start-dt "%s"'
+METRICS_BAR = 'termgraph %s --color {red,green} --start-dt "%s" 2>/dev/null'
