@@ -1,9 +1,10 @@
 from pyfiglet import figlet_format
 from typing import List
-from colorama import Fore, Style
+from colorama import Fore, Style, Back
 import sys
 import logging
 from sylo.models import Durations, Config
+import textwrap as tr
 
 
 logger = logging.getLogger(__name__)
@@ -13,8 +14,12 @@ config = Config()
 
 
 class Display:
-    def __init__(self, theme_color: str = config.theme_color):
+    def __init__(self,
+                 theme_color: str = config.theme_color,
+                 pom_name: str = config.pom_name,
+                 ):
         self.theme = self.color_map(theme_color)
+        self.pom_name = pom_name
 
     def col(self, string: str, color: str = None):
         if color:
@@ -22,6 +27,10 @@ class Display:
         else:
             return f"{self.theme}{string}{Style.RESET_ALL}"
 
+    def print_poms(self, string: str):
+        col_str = self.col(string, 'black')
+        return f"{Back.YELLOW}{col_str}{Style.RESET_ALL}"
+
     def print_timer(self, mode: str, timer_val: int, tasks: List = None):
         if mode == "work":
             self.print_header_small()
@@ -48,8 +57,12 @@ class Display:
             f"{self.col('to stop timer.')}",
         )
 
-    def print_insights(self):
+    def print_insights(self, durations: Durations):
         print(
+            f"\nTotal {self.col('work', 'red')} today:           "
+            f"{self.col(str(int(durations.total_work_mins)), 'yellow')} minutes"
+            f"\nTotal {self.col('rest', 'green')} today:           "
+            f"{self.col(str(int(durations.total_rest_mins)), 'yellow')} minutes\n"
             f"\n{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
             f"{self.col('to return to main menu.')}"
@@ -66,7 +79,7 @@ class Display:
 
     def print_options(self):
         print(
-            "Additional commands;"
+            f"{self.col('Additional commands;')}"
             f"\n{self.col('S', 'yellow')}{self.col('       --    Swap upcoming timer')}"
             f"\n{self.col('T', 'yellow')}{self.col('       --    Show task view')}"
             f"\n{self.col('I', 'yellow')}{self.col('       --    Show insights view')}"
@@ -81,7 +94,7 @@ class Display:
         )
 
     def print_today_yesterday_tasks(self, day: str):
-        print(f"{self.col(day)}\n")
+        print(f"{self.col(day)}")
 
     def print_offer_options(self):
         print(f"{self.col('Press')} {self.col('H', 'yellow')} {self.col('for Help.')}")
@@ -90,21 +103,37 @@ class Display:
         print(
             f"{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
-            f"{self.col('to go back, or')} "
-            f"{self.col('N', 'yellow')} "
+            f"{self.col('to go back')} "
+            f"\n{self.col('Press')} {self.col('N', 'yellow')} "
             f"{self.col('to add a new task')}"
+            f"\n{self.col('Press')} {self.col('C', 'yellow')} "
+            f"{self.col('to toggle completion of a task')}"
+            f"\n{self.col('Press')} {self.col('D', 'yellow')} "
+            f"{self.col('to delete a task')}"
         )
 
     def print_new_task(self):
         print(f"{self.col('Input a new task')}")
 
+    def print_edit_task(self):
+        print(f"{self.col('Pick a task to complete/put back')}")
+
+    def print_remove_task(self):
+        print(f"{self.col('Pick a task to DELETE')}")
+
+    def fix_indent(self):
+        num = len('pomodoro') - len(self.pom_name)
+        fix_str = ''
+        for no in range(0, num):
+            fix_str += ' '
+        return fix_str
+
     def print_splash(self, durations: Durations, mode: str):
         print(
-            f"Total {self.col('work', 'red')} today:           "
-            f"{self.col(str(int(durations.total_work_mins)), 'yellow')} minutes"
-            f"\nTotal {self.col('rest', 'green')} today:           "
-            f"{self.col(str(int(durations.total_rest_mins)), 'yellow')} minutes"
-            f"\nUpcoming timer:     {self.col(mode.upper(), self._set_mode_color(mode, durations))}"
+            f"\nTotal {self.add_plurality(self.pom_name)} today:{self.fix_indent()}      "
+            f"{self.print_poms(str(int(durations.poms)))}"
+            f"\nUpcoming timer:     "
+            f"        {self.col(mode.upper(), self._set_mode_color(mode, durations))}"
             f"\n"
         )
 
@@ -136,9 +165,36 @@ class Display:
 
     def print_tasks(self, tasks: List = None):
         if tasks:
-            print(f'{self.col(f"Tasks", "yellow")}')
-            print("\n".join("".join(map(str, f"{self.col(t[0], 'yellow')}   "
-                                             f"{t[1]}   --  {t[2]}")) for t in tasks))
+            print(f'{self.col(f"Completed tasks")}\n')
+            print(
+                "\n".join("".join(map(str,
+                                      f"{self.trim_string(self.col(t[2],'green'),45)}"))
+                          for t in tasks if t[4] == '1'))
+            print("\n")
+            print(f'{self.col(f"Incomplete tasks")}\n')
+            print("\n".join("".join(map(str,
+                                        f"{self.add_plurality(self.pom_name)}: "
+                                        f"{self.print_poms(t[3])}"
+                                        f"\n{tr.fill(t[2], 45)}\n"))
+                            for t in tasks if t[4] == '0'))
+            print("\n")
+
+    def print_tasks_with_id(self, tasks: List = None):
+        if tasks:
+            print(f'{self.col(f"Completed tasks")}\n')
+            print(
+                "\n".join("".join(map(str,
+                                      f"{self.col(t[0], 'yellow')}   "
+                                      f"{self.trim_string(self.col(t[2],'green'),45)}"))
+                          for t in tasks if t[4] == '1'))
+            print("\n")
+            print(f'{self.col(f"Incomplete tasks")}\n')
+            print("\n".join("".join(map(str,
+                                        f"{self.col(t[0], 'yellow')}   "
+                                        f"{self.add_plurality(self.pom_name)}: "
+                                        f"{self.print_poms(t[3])}"
+                                        f"\n{tr.fill(t[2], 45)}\n"))
+                            for t in tasks if t[4] == '0'))
             print("\n")
 
     def print_header_small(self):
@@ -170,3 +226,14 @@ class Display:
             return durations.rest.bar_color
         else:
             return durations.work.bar_color
+
+    @staticmethod
+    def add_plurality(string: str):
+        if string[-1] == 's':
+            return string
+        else:
+            return string + 's'
+
+    @staticmethod
+    def trim_string(string: str, max_len: int) -> str:
+        return (string[:max_len] + '..') if len(string) > max_len else string
