@@ -37,6 +37,7 @@ class Durations:
     rest = Rest
     total_work_mins: float = 0
     total_rest_mins: float = 0
+    poms = float = 0
 
     def __post_init__(self):
         self.work = Work()
@@ -49,6 +50,7 @@ class Config:
     audio_file = None
     work_time = 25
     rest_time = 5
+    pom_name = "Pomodoro"
 
 
 class ConfigFile:
@@ -68,12 +70,22 @@ class ConfigFile:
                 general = config_file["general"]
                 logger.info(f"CONFIG: general from file: {general}")
                 config.theme_color = general["theme"]
+                logger.info(f"CONFIG:set theme_color to {config.theme_color}")
+
             except KeyError as k:
                 logger.info(k)
                 pass
             try:
                 general = config_file["general"]
                 config.audio_file = general["audio_file"]
+                logger.info(f"CONFIG:set audio_file to {config.audio_file}")
+            except KeyError as k:
+                logger.info(k)
+                pass
+            try:
+                general = config_file["general"]
+                config.pom_name = general["time_segment_name"]
+                logger.info(f"CONFIG:set pom_name to {config.pom_name}")
             except KeyError as k:
                 logger.info(k)
                 pass
@@ -93,7 +105,7 @@ class ConfigFile:
 class DataPersistence:
     def __init__(self, data_file: str = DATA_FILE_LOCATION):
         self.data_file = data_file
-        self.file_cols = ["date", "time_worked", "time_rested"]
+        self.file_cols = ["date", "time_worked", "time_rested", "poms"]
 
     def data_refresh(self, durations: Durations):
         new_df = self.fetch_and_update_values(durations, TODAY_STR)
@@ -106,16 +118,20 @@ class DataPersistence:
             logger.info("data_load_on_boot Found data for today")
             work_time_today = float(filtered_dates["time_worked"])
             rest_time_today = float(filtered_dates["time_rested"])
+            poms_today = float(filtered_dates["poms"])
             logger.info(f"Work time loaded on boot: {work_time_today}")
             logger.info(f"Rest time loaded on boot: {rest_time_today}")
+            logger.info(f"Rest time loaded on boot: {poms_today}")
             durations.total_work_mins = work_time_today
             durations.total_rest_mins = rest_time_today
+            durations.poms = poms_today
         except Exception:
             logger.info("data_load_on_boot NO DATA for today")
             filtered_dates = None
         if filtered_dates is None:
             durations.total_rest_mins = 0
             durations.total_work_mins = 0
+            durations.poms = 0
 
     def _read_file(self):
         df = pd.read_csv(self.data_file, header=None, sep=",")
@@ -130,6 +146,7 @@ class DataPersistence:
                 "date": [date],
                 "time_worked": [durations.total_work_mins],
                 "time_rested": [durations.total_rest_mins],
+                "poms": [durations.poms]
             },
             columns=self.file_cols,
             dtype="float",
@@ -157,3 +174,32 @@ def get_max_id_in_csv(tasks: List):
         return max(t[0] for t in tasks)
     else:
         return 0
+
+
+def complete_task(task_id: str):
+    row_list = []
+    with open(TASK_FILE_LOCATION, 'r') as readFile:
+        reader = csv.reader(readFile)
+        for row in reader:
+            row_list.append(row)
+            if row[0] == task_id:
+                if row[4] == '1':
+                    row[4] = '0'
+                else:
+                    row[4] = '1'
+    with open(TASK_FILE_LOCATION, 'w') as writeFile:
+        writer = csv.writer(writeFile)
+        writer.writerows(row_list)
+
+
+def remove_task(task_id: str):
+    row_list = []
+    with open(TASK_FILE_LOCATION, 'r') as readFile:
+        reader = csv.reader(readFile)
+        for row in reader:
+            row_list.append(row)
+            if row[0] == task_id:
+                row_list.remove(row)
+    with open(TASK_FILE_LOCATION, 'w') as writeFile:
+        writer = csv.writer(writeFile)
+        writer.writerows(row_list)
