@@ -13,7 +13,9 @@ from sylo.models import (
     DataPersistence,
     get_tasks,
     ConfigFile,
-    get_max_id_in_csv
+    get_max_id_in_csv,
+    complete_task,
+    remove_task,
 )
 from sylo.definitions import (
     TASK_FILE_LOCATION,
@@ -168,12 +170,13 @@ class Task:
     def __init__(self):
         self.description = None
         self.date = TODAY_STR
-        self.complete = False
+        self.complete = 0
+        self.effort = 1
 
     def write_task_to_file(self):
         tasks = get_tasks()
         max_id = get_max_id_in_csv(tasks)
-        fields = [int(max_id) + 1, self.date, self.description, self.complete]
+        fields = [int(max_id) + 1, self.date, self.description, self.effort, self.complete]
         with open(TASK_FILE_LOCATION, "a") as f:
             writer = csv.writer(f)
             writer.writerow(fields)
@@ -223,24 +226,53 @@ class Sylo:
         self.tasks = get_tasks(date)
         self.input_loop()
 
+    def show_task(self, dates, with_id: bool = False):
+        for date, day in zip(dates, ['YESTERDAY', 'TODAY']):
+            print('\n')
+            display.print_today_yesterday_tasks(day)
+            print(display.col('-----------------------------------------\n'))
+            self.tasks = get_tasks(date)
+            if with_id is False:
+                display.print_tasks(self.tasks)
+            else:
+                display.print_tasks_with_id(self.tasks)
+
     def edit_task_menu(self, dates: List):
         clear_screen()
         task = Task()
         display.print_header_small()
-        for date, day in zip(dates, ['YESTERDAY', 'TODAY']):
-            display.print_today_yesterday_tasks(day)
-            self.tasks = get_tasks(date)
-            display.print_tasks(self.tasks)
+        self.show_task(dates)
         display.print_add_task_or_quit()
         usr_input = input(cursor)
         if usr_input == "":
             self.input_loop()
         while usr_input.lower() == "n":
             display.print_new_task()
-            task.description = input('Description >> ')
+            task.description = input(display.col('Description >> ', 'yellow'))
+            task.effort = input(
+                display.col(f'Effort (in'
+                            f' {display.add_plurality(display.pom_name)}) >> ',
+                            'yellow')
+            )
             task.write_task_to_file()
             self.edit_task_menu(dates)
-        while usr_input.lower() not in ('', 'n'):
+        while usr_input.lower() == 'c':
+            clear_screen()
+            display.print_header_small()
+            self.show_task(dates, True)
+            display.print_edit_task()
+            comp_input = input(display.col('Task id >> ', 'yellow'))
+            complete_task(comp_input)
+            self.edit_task_menu(dates)
+        while usr_input.lower() == 'd':
+            clear_screen()
+            display.print_header_small()
+            self.show_task(dates, True)
+            display.print_remove_task()
+            comp_input = input(display.col('Task id >> ', 'yellow'))
+            remove_task(comp_input)
+            self.edit_task_menu(dates)
+        while usr_input.lower() not in ('', 'n', 'c'):
             self.edit_task_menu(dates)
 
     def switch_modes(self):
@@ -258,7 +290,7 @@ class Sylo:
         metrics = Insights()
         metrics.print_bar()
         metrics.print_heat()
-        display.print_insights()
+        display.print_insights(durations=self.durations)
         input(cursor)
         self.input_loop()
 
@@ -281,6 +313,7 @@ class Sylo:
             if complete is True:
                 self.sound_obj.play_sound()
                 self.durations.total_work_mins += self.durations.work.mins
+                self.durations.poms += 1
             else:
                 self.durations.total_work_mins += secs_passed
             self.mode = flip_mode(self.mode)
@@ -340,6 +373,7 @@ def config_allocation(args, config, durations: Durations):
         config.theme_color = args.theme
     logger.info(config.theme_color)
     display.theme = display.color_map(config.theme_color)
+    display.pom_name = config.pom_name
     logger.info(display.theme)
     if args.audio_file:
         config.audio_file = args.audio_file
