@@ -16,9 +16,10 @@ def run_subprocess(script: str):
         sys.exit()
     try:
         subprocess.run(script, shell=True, check=True, timeout=30)
-    except subprocess.CalledProcessError as e:
-        print(e.output)
-        logger.warning(e.output)
+    except subprocess.CalledProcessError:
+        print('Insights panel not loading as there is no data to display. '
+              '\nTry working for a few mins then check back later.')
+        print('\n')
 
 
 def clear_screen():
